@@ -71,7 +71,7 @@ ONU::ONU(GameAutomaton* automaton,
   }
 #endif
   m_font.family = "URW Chancery L";
-  m_font.size = (uint)(13*m_zoom);
+  m_font.size = (int)(13*m_zoom);
   m_font.weight = QFont::Bold;
   m_font.italic = true;
   m_font.foregroundColor = "black";
@@ -109,7 +109,7 @@ ONU::ONU(GameAutomaton* automaton,
     m_snapshot = QPixmap(QStandardPaths::locate(QStandardPaths::AppDataLocation, m_skin + "/Images/snapshot.jpg"));
     if (m_snapshot.isNull())
     {
-      qCCritical(KSIRK_LOG) << "Was not able to load the snapshot image: " << QStandardPaths::locate(QStandardPaths::AppDataLocation, m_skin + "/Images/snapshot.jpg") << endl;
+      qCCritical(KSIRK_LOG) << "Was not able to load the snapshot image: " << QStandardPaths::locate(QStandardPaths::AppDataLocation, m_skin + "/Images/snapshot.jpg");
     }
     QPixmapCache::insert(m_skin+"snapshot", m_snapshot);
   }
@@ -158,7 +158,7 @@ ONU::ONU(GameAutomaton* automaton,
     countriesMaskPix = QPixmap(mapMaskFileName);
     if (countriesMaskPix.isNull())
     {
-      qCCritical(KSIRK_LOG) << "Was not able to load the map mask image: " << mapMaskFileName << endl;
+      qCCritical(KSIRK_LOG) << "Was not able to load the map mask image: " << mapMaskFileName ;
     }
     QPixmapCache::insert(m_skin+"mapmask", countriesMaskPix);
   }
@@ -222,7 +222,7 @@ ONU::ONU(GameAutomaton* automaton,
 
   KConfigGroup fontgroup = config.group("font");
   m_font.family = fontgroup.readEntry("family","URW Chancery L");
-  m_font.size = fontgroup.readEntry("size",(uint)(13*m_zoom));
+  m_font.size = fontgroup.readEntry("size",(int)(13*m_zoom));
   QString w = fontgroup.readEntry("weight", "bold");;
   if (w == "normal")
   {
@@ -334,7 +334,7 @@ ONU::ONU(GameAutomaton* automaton,
           goal->continents().push_back(continentId);
         else
         {
-          qCDebug(KSIRK_LOG) << "Unknown continent " << continentId << " in skin " << m_skin << endl;
+          qCDebug(KSIRK_LOG) << "Unknown continent " << continentId << " in skin " << m_skin ;
         }
       }
     }
@@ -512,15 +512,15 @@ unsigned int ONU::getNbCountries() const
 
 void ONU::saveXml(QTextStream& xmlStream)
 {
-  xmlStream << "<ONU file=\"" << m_configFileName << "\" >" << endl;
+  xmlStream << "<ONU file=\"" << m_configFileName << "\" >";
 
-  xmlStream << "<countries>" << endl;
+  xmlStream << "<countries>";
   foreach (Country *c, countries)
   {
       c->saveXml(xmlStream);
   }
-  xmlStream << "</countries>" << endl;
-  xmlStream << "</ONU>" << endl;  
+  xmlStream << "</countries>";
+  xmlStream << "</ONU>";  
 }
 
 unsigned int ONU::width() const
@@ -640,7 +640,7 @@ void ONU::applyZoomFactor(qreal zoomFactor)
 
   m_zoom *= zoomFactor;
 
-  //m_font.size = (unsigned int)(m_font.size*m_zoom);
+  //m_font.size = (int)(m_font.size*m_zoom);
   //m_width = (unsigned int)(m_width *m_zoom);
   //m_height = (unsigned int)(m_height *m_zoom);
 
@@ -659,13 +659,13 @@ void ONU::applyZoomFactorFast(qreal zoomFactor)		//benj
 /** Zoom 2 : Second method , Very performent.  Carefull ! Can cause the game to lag. 
  To try this, comment all the first method and uncomment these lines
 */
-  qCDebug(KSIRK_LOG) << "zoomFactor FASTTTTTTT"<<endl;
+  qCDebug(KSIRK_LOG) << "zoomFactor FASTTTTTTT";
   int nbLimitZooms = 6;
 
   //Application of zoom
   if (zoomFactor > 1 && m_nbZooms < nbLimitZooms)
   {
-    m_font.size = (unsigned int)(m_font.size*zoomFactor);
+    m_font.size = (int)(m_font.size*zoomFactor);
     m_width = (unsigned int)(m_width *zoomFactor);
     m_height = (unsigned int)(m_height *zoomFactor);
 
@@ -684,7 +684,7 @@ void ONU::applyZoomFactorFast(qreal zoomFactor)		//benj
   }
   else if (zoomFactor < 1 && m_nbZooms > -nbLimitZooms)
   {
-    m_font.size = (unsigned int)(m_font.size*zoomFactor);
+    m_font.size = (int)(m_font.size*zoomFactor);
     m_width = (unsigned int)(m_width *zoomFactor);
     m_height = (unsigned int)(m_height *zoomFactor);
 
